[Jboss-cvs] JBossAS SVN: r56392 - in branches/MC_VDF_WORK/jmx: . src/main/org/jboss/mx/loading

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Tue Aug 29 02:56:45 EDT 2006


Author: scott.stark at jboss.org
Date: 2006-08-29 02:56:40 -0400 (Tue, 29 Aug 2006)
New Revision: 56392

Modified:
   branches/MC_VDF_WORK/jmx/.classpath
   branches/MC_VDF_WORK/jmx/build.xml
   branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/ClassLoadingTaskDCL.java
   branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/DomainClassLoaderUCLImpl.java
   branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/LoadMgrDCL.java
   branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/ResourceInfo.java
   branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/UnifiedLoaderRepositoryDCL.java
   branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/UnifiedLoaderRepositoryDCLMBean.java
Log:
More work on porting the legacy UCL to the DomainClassLoader

Modified: branches/MC_VDF_WORK/jmx/.classpath
===================================================================
--- branches/MC_VDF_WORK/jmx/.classpath	2006-08-29 06:56:37 UTC (rev 56391)
+++ branches/MC_VDF_WORK/jmx/.classpath	2006-08-29 06:56:40 UTC (rev 56392)
@@ -10,5 +10,6 @@
 	<classpathentry kind="lib" path="/thirdparty/dom4j/lib/dom4j.jar"/>
 	<classpathentry kind="src" path="/j2se"/>
 	<classpathentry kind="src" path="/mbeans"/>
+	<classpathentry sourcepath="/home/svn/JBossMC/jbossmc/container/src/main" kind="lib" path="/thirdparty/jboss/microcontainer/lib/jboss-container.jar"/>
 	<classpathentry kind="output" path="output/eclipse-classes"/>
 </classpath>

Modified: branches/MC_VDF_WORK/jmx/build.xml
===================================================================
--- branches/MC_VDF_WORK/jmx/build.xml	2006-08-29 06:56:37 UTC (rev 56391)
+++ branches/MC_VDF_WORK/jmx/build.xml	2006-08-29 06:56:40 UTC (rev 56392)
@@ -143,16 +143,8 @@
     <property name="module.name" value="jbossmx"/>
     <property name="module.Name" value="JBoss/JMX"/>
 
-      <!-- xdoclet -->
-      <path id="xdoclet.task.classpath">
-        <path refid="javac.classpath"/>
-        <fileset dir="${xdoclet.xdoclet.lib}">
-          <include name="**/*.jar"/>
-        </fileset>
-      </path>
-      <property name="xdoclet.task.classpath"
-            refid="xdoclet.task.classpath"/>
-
+    <property name="javac.target" value="1.5"/>
+    <property name="javac.source" value="1.5"/>
       <!-- Where build generated files will go -->
       <property name="build.reports" value="${module.output}/reports"/>
       <property name="build.classes" value="${module.output}/classes"/>

Modified: branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/ClassLoadingTaskDCL.java
===================================================================
--- branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/ClassLoadingTaskDCL.java	2006-08-29 06:56:37 UTC (rev 56391)
+++ branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/ClassLoadingTaskDCL.java	2006-08-29 06:56:40 UTC (rev 56392)
@@ -45,7 +45,7 @@
 
    protected String classname;
    protected Thread requestingThread;
-   protected LegacyDomainClassLoader requestingClassLoader;
+   protected DomainClassLoaderUCLImpl requestingClassLoader;
    protected Class loadedClass;
    protected int loadOrder = Integer.MAX_VALUE;
    protected int stopOrder = Integer.MAX_VALUE;
@@ -85,7 +85,7 @@
    class ThreadTask
    {
       /** The class loader for the classname package */
-      LegacyDomainClassLoader ucl;
+      DomainClassLoaderUCLImpl ucl;
       /** The thread that owns the ucl monitor */
       Thread t;
       /** The relative order of the task. If o0 < o1 then the class loaded
@@ -94,7 +94,7 @@
       int order;
       boolean releaseInNextTask;
 
-      ThreadTask(LegacyDomainClassLoader ucl, Thread t, int order,
+      ThreadTask(DomainClassLoaderUCLImpl ucl, Thread t, int order,
          boolean releaseInNextTask)
       {
          this.ucl = ucl;
@@ -146,13 +146,13 @@
       }
    }
 
-   protected ClassLoadingTaskDCL(String classname, LegacyDomainClassLoader requestingClassLoader,
+   protected ClassLoadingTaskDCL(String classname, DomainClassLoaderUCLImpl requestingClassLoader,
          Thread requestingThread)
    {
       this(classname, requestingClassLoader, requestingThread, Integer.MAX_VALUE);
    }
    
-   protected ClassLoadingTaskDCL(String classname, LegacyDomainClassLoader requestingClassLoader,
+   protected ClassLoadingTaskDCL(String classname, DomainClassLoaderUCLImpl requestingClassLoader,
       Thread requestingThread, int stopAt)
    {
       this.requestingThread = requestingThread;
@@ -188,7 +188,7 @@
       return buffer.toString();
    }
 
-   ThreadTask newThreadTask(LegacyDomainClassLoader ucl, Thread t, int order,
+   ThreadTask newThreadTask(DomainClassLoaderUCLImpl ucl, Thread t, int order,
       boolean reschedule, boolean releaseInNextTask)
    {
       // Only update the threadTaskCount if this is not a reschedule

Modified: branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/DomainClassLoaderUCLImpl.java
===================================================================
--- branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/DomainClassLoaderUCLImpl.java	2006-08-29 06:56:37 UTC (rev 56391)
+++ branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/DomainClassLoaderUCLImpl.java	2006-08-29 06:56:40 UTC (rev 56392)
@@ -170,6 +170,11 @@
       return new ObjectName(name);
    }
 
+   public String[] getPackagNames()
+   {
+      // TODO Auto-generated method stub
+      return null;
+   }
    public void unregister()
    {
       super.unregister();
@@ -250,13 +255,14 @@
          /* Process class loading tasks needing this UCL until our task has
             been completed by the thread owning the required UCL(s).
           */
-         if( LoadMgrDCL.beginLoadTask(task, domain) == false )
+         UnifiedLoaderRepositoryDCL repository = (UnifiedLoaderRepositoryDCL) domain;
+         if( LoadMgrDCL.beginLoadTask(task, repository) == false )
          {
             while( task.threadTaskCount != 0 )
             {
                try
                {
-                  LoadMgrDCL.nextTask(t, task, domain);
+                  LoadMgrDCL.nextTask(t, task, repository);
                }
                catch(InterruptedException e)
                {

Modified: branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/LoadMgrDCL.java
===================================================================
--- branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/ResourceInfo.java	2006-08-29 06:56:37 UTC (rev 56391)
+++ branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/ResourceInfo.java	2006-08-29 06:56:40 UTC (rev 56392)
@@ -25,14 +25,15 @@
 
 /**
  *
- * @author  starksm
+ * @author Scott.Stark at jboss.org
+ * @version $Revision:$
  */
-class ResourceInfo
+class ResourceInfo<T>
 {
    URL url;
-   ClassLoader cl;
+   T cl;
 
-   ResourceInfo(URL url, ClassLoader cl)
+   ResourceInfo(URL url, T cl)
    {
       this.url = url;
       this.cl = cl;

Modified: branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/UnifiedLoaderRepositoryDCL.java
===================================================================
--- branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/UnifiedLoaderRepositoryDCL.java	2006-08-29 06:56:37 UTC (rev 56391)
+++ branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/UnifiedLoaderRepositoryDCL.java	2006-08-29 06:56:40 UTC (rev 56392)
@@ -25,6 +25,7 @@
 import java.net.URL;
 import java.net.URLClassLoader;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -47,6 +48,7 @@
 
 import org.jboss.classloading.spi.ClassLoadingDomain;
 import org.jboss.classloading.spi.DomainClassLoader;
+import org.jboss.classloading.spi.Translator;
 import org.jboss.logging.Logger;
 import org.jboss.mx.util.JBossNotificationBroadcasterSupport;
 import org.jboss.util.Classes;
@@ -349,7 +351,7 @@
             DomainClassLoader ucl = (DomainClassLoader) nextCL;
             try
             {
-               Enumeration resURLs = ucl.loadResourceLocally(name);
+               Enumeration<URL> resURLs = ucl.findResourcesLocally(name);
                while (resURLs.hasMoreElements())
                {
                   Object res = resURLs.nextElement();
@@ -362,6 +364,11 @@
          }
       }
    }
+   public Enumeration<URL> findResources(String arg0)
+   {
+      // TODO Auto-generated method stub
+      return null;
+   }
 
    /** As opposed to classes, resource are not looked up in a global cache,
     * since it is possible that 2 classloaders have the same resource name
@@ -648,16 +655,7 @@
    public void addClassLoader(DomainClassLoader loader)
    {
       // if you come to us as UCL we send you straight to the orbit
-      if (loader instanceof DomainClassLoader)
-         addDomainClassLoader((DomainClassLoader) loader);
-      else if (loader instanceof URLClassLoader)
-      {
-         addURLClassLoader((URLClassLoader) loader);
-      }
-      else
-      {
-         log.warn("Tried to add non-URLClassLoader.  Ignored");
-      } // end of else
+      addDomainClassLoader((DomainClassLoader) loader);
    }
 
    public boolean addClassLoaderURL(DomainClassLoader cl, URL url)
@@ -685,7 +683,7 @@
          // See if the URL is associated with a class loader
          if (classLoaderURLs.contains(url) == false)
          {
-            updatePackageMap(ucl, url);
+            updatePackageMap(ucl);
             classLoaderURLs.add(url);
             added = true;
             // Check for a dynamic URL
@@ -703,26 +701,17 @@
    private void addDomainClassLoader(DomainClassLoader cl)
    {
       cl.setDomain(this);
-      // See if this URL already exists
-      URL url = cl.getURL();
       boolean added = false;
       synchronized (classLoaders)
       {
          boolean exists = false;
-         if (cl instanceof UnifiedClassLoader)
-            exists = classLoaderURLs.contains(url);
-         // If already present will not be added
-         if (!exists)
-         {
-            if (url != null)
-               classLoaderURLs.add(url);
-            added = classLoaders.add(cl);
-         }
+         URL[] cp = cl.getClasspath();
+         classLoaderURLs.addAll(Arrays.asList(cp));
+         added = classLoaders.add(cl);
          if (added)
          {
             log.debug("Adding " + cl);
             addedCount++;
-            cl.setAddedOrder(addedCount);
             updatePackageMap(cl);
          }
          else
@@ -732,23 +721,6 @@
       }
    }
 
-   private void addURLClassLoader(URLClassLoader loader)
-   {
-      URL[] urls = loader.getURLs();
-      int count = urls != null && urls.length > 0 ? urls.length : 0;
-      URL origURL = count > 0 ? urls[0] : null;
-      DomainClassLoaderUCLImpl ucl3 = new DomainClassLoaderUCLImpl(origURL, origURL, this);
-      addDomainClassLoader(ucl3);
-      synchronized (classLoaders)
-      {
-         nonUCLClassLoader.put(loader, ucl3);
-      }
-      for (int i = 1; i < count; i++)
-      {
-         this.addClassLoaderURL(ucl3, urls[i]);
-      }
-   }
-   
    /** Walk through the class loader URL to see what packages it is capable
     of handling
     */
@@ -756,7 +728,7 @@
    {
       try
       {
-         String[] pkgNames = ClassLoaderUtils.updatePackageMap(cl, packagesMap);
+         String[] pkgNames = cl.getPackagNames();
          loaderToPackagesMap.put(cl, pkgNames);
       }
       catch (Exception e)
@@ -768,26 +740,6 @@
       }
    }
 
-   /** Walk through the new URL to update the packages the DomainClassLoader is
-    * capable of handling
-    */
-   private void updatePackageMap(DomainClassLoader cl, URL url)
-   {
-      try
-      {
-         String[] prevPkgNames = (String[]) loaderToPackagesMap.get(cl);
-         String[] pkgNames = ClassLoaderUtils.updatePackageMap(cl, packagesMap, url, prevPkgNames);
-         loaderToPackagesMap.put(cl, pkgNames);
-      }
-      catch (Exception e)
-      {
-         if (log.isTraceEnabled())
-            log.trace("Failed to update pkgs for cl=" + cl, e);
-         else
-            log.debug("Failed to update pkgs for cl=" + cl, e);
-      }
-   }
-
    /** Remove the class loader from the repository. This synchronizes on the
     * this.classLoaders
     */

Modified: branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/UnifiedLoaderRepositoryDCLMBean.java
===================================================================
--- branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/UnifiedLoaderRepositoryDCLMBean.java	2006-08-29 06:56:37 UTC (rev 56391)
+++ branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/UnifiedLoaderRepositoryDCLMBean.java	2006-08-29 06:56:40 UTC (rev 56392)
@@ -4,7 +4,7 @@
 import java.util.Set;
 
 import org.jboss.classloading.spi.DomainClassLoader;
-import org.jboss.util.loading.Translator;
+import org.jboss.classloading.spi.Translator;
 
 public interface UnifiedLoaderRepositoryDCLMBean
 {




More information about the jboss-cvs-commits mailing list
--- branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/LoadMgrDCL.java	2006-08-29 06:56:37 UTC (rev 56391)
+++ branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/LoadMgrDCL.java	2006-08-29 06:56:40 UTC (rev 56392)
@@ -35,7 +35,7 @@
 
 import org.jboss.classloading.spi.DomainClassLoader;
 import org.jboss.logging.Logger;
-import org.jboss.mx.loading.ClassLoadingTask.ThreadTask;
+import org.jboss.mx.loading.ClassLoadingTaskDCL.ThreadTask;
 
 
 /** A utility class used by the DomainClassLoaderUCLImpl to manage the thread
@@ -70,14 +70,14 @@
     */
    public static class PkgClassLoader
    {
-      public final RepositoryClassLoader ucl;
+      public final DomainClassLoaderUCLImpl ucl;
       public final int order;
 
-      public PkgClassLoader(RepositoryClassLoader ucl)
+      public PkgClassLoader(DomainClassLoaderUCLImpl ucl)
       {
          this(ucl, Integer.MAX_VALUE);
       }
-      public PkgClassLoader(RepositoryClassLoader ucl, int order)
+      public PkgClassLoader(DomainClassLoaderUCLImpl ucl, int order)
       {
          this.ucl = ucl;
          this.order = order;
@@ -98,16 +98,16 @@
     */ 
    private static class ResourceAction implements PrivilegedAction
    {
-      RepositoryClassLoader ucl;
+      DomainClassLoader ucl;
       String classRsrcName;
-      ResourceAction(RepositoryClassLoader ucl, String classRsrcName)
+      ResourceAction(DomainClassLoader ucl, String classRsrcName)
       {
          this.ucl = ucl;
          this.classRsrcName = classRsrcName;
       }
       public Object run()
       {
-         URL url = ucl.getResourceLocally(classRsrcName);
+         URL url = ucl.loadResourceLocally(classRsrcName);
          ucl = null;
          classRsrcName = null;
          return url;
@@ -145,19 +145,19 @@
     * initiate the process of loading the requested class. This first attempts
     * to load the class from the repository cache, and then the class loaders
     * in the repsository. If the package of the class is found in the repository
     * then one or more ThreadTask are created to complete the ClassLoadingTask.
     * The ThreadTask are assigned to the threads that own the associated UCL3
     * monitor. If no class loader serves the class package, then the requesting
     * class loader is asked if it can load the class.
     *
     * @return true if the class could be loaded from the cache or requesting
     * UCL3, false to indicate the calling thread must process the
     * tasks assigned to it until the ClassLoadingTask state is FINISHED
     * @exception ClassNotFoundException if there is no chance the class can
     * be loaded from the current repository class loaders.
     */
-   public static boolean beginLoadTask(ClassLoadingTask task,
-      UnifiedLoaderRepository3 repository)
+   public static boolean beginLoadTask(ClassLoadingTaskDCL task,
+         UnifiedLoaderRepositoryDCL repository)
       throws ClassNotFoundException
    {
       boolean trace = log.isTraceEnabled();
@@ -169,7 +169,7 @@
       if( cls != null )
       {
          task.loadedClass = cls;
-         task.state = ClassLoadingTask.FINISHED;
+         task.state = ClassLoadingTaskDCL.FINISHED;
          if( trace )
             log.trace("End beginLoadTask, loadClassFromCache, classname: "+task.classname);
          return true;
@@ -199,7 +199,7 @@
             if( cls != null )
             {
                task.loadedClass = cls;
-               task.state = ClassLoadingTask.FINISHED;
+               task.state = ClassLoadingTaskDCL.FINISHED;
                if( trace )
                   log.trace("End beginLoadTask, loadClassFromClassLoader");
                return true;
@@ -229,18 +229,18 @@
          to be augmented.
        */
       Iterator iter = pkgSet.iterator();
-      RepositoryClassLoader theUCL = null;
+      DomainClassLoaderUCLImpl theUCL = null;
       int order = Integer.MAX_VALUE;
       while( iter.hasNext() )
       {
          Object next = iter.next();
          int uclOrder;
-         RepositoryClassLoader ucl;
+         DomainClassLoaderUCLImpl ucl;
          // This may be either a PkgClassLoader or a UCL3
-         if( next instanceof RepositoryClassLoader )
+         if( next instanceof DomainClassLoaderUCLImpl )
          {
-            ucl = (RepositoryClassLoader) next;
-            uclOrder = ucl.getAddedOrder();
+            ucl = (DomainClassLoaderUCLImpl) next;
+            uclOrder = 0; //ucl.getAddedOrder();
          }
          else
          {
@@ -263,7 +263,7 @@
          }
          else
          {
-            url = ucl.getResourceLocally(classRsrcName);
+            url = ucl.loadResourceLocally(classRsrcName);
          }
 
          if( url != null && uclOrder < order )
@@ -294,7 +294,7 @@
          if( cls != null )
          {
             task.loadedClass = cls;
-            task.state = ClassLoadingTask.FINISHED;
+            task.state = ClassLoadingTaskDCL.FINISHED;
             if( trace )
                log.trace("End beginLoadTask, loadClassFromClassLoader");
             return true;
@@ -316,7 +316,7 @@
       }
 
       scheduleTask(task, theUCL, order, false, trace);
-      task.state = ClassLoadingTask.FOUND_CLASS_LOADER;
+      task.state = ClassLoadingTaskDCL.FOUND_CLASS_LOADER;
       if( trace )
          log.trace("End beginLoadTask, task="+task);
 
@@ -330,8 +330,8 @@
     * processes class loading tasks that must be handled by its UCL3. The
     * active set of threads loading classes form a pool of cooperating threads.
     */
-   public static void nextTask(Thread t, ClassLoadingTask task,
-      UnifiedLoaderRepository3 repository)
+   public static void nextTask(Thread t, ClassLoadingTaskDCL task,
+         UnifiedLoaderRepositoryDCL repository)
       throws InterruptedException
    {
       boolean trace = log.isTraceEnabled();
@@ -348,7 +348,7 @@
                log.trace("Begin nextTask(WAIT_ON_EVENT), task="+task);
             try
             {
-               task.state = ClassLoadingTask.WAIT_ON_EVENT;
+               task.state = ClassLoadingTaskDCL.WAIT_ON_EVENT;
                taskList.wait();
             }
             catch(InterruptedException e)
@@ -368,24 +368,24 @@
          // See if the task is complete
          if( task.threadTaskCount == 0 )
          {
-            task.state = ClassLoadingTask.FINISHED;
+            task.state = ClassLoadingTaskDCL.FINISHED;
             log.trace("End nextTask(FINISHED), task="+task);
             return;
          }
       }
 
       ThreadTask threadTask = (ThreadTask) taskList.remove(0);
-      ClassLoadingTask loadTask = threadTask.getLoadTask();
+      ClassLoadingTaskDCL loadTask = threadTask.getLoadTask();
       if( trace )
          log.trace("Begin nextTask("+taskList.size()+"), loadTask="+loadTask);
 
-      RepositoryClassLoader ucl3 = threadTask.ucl;
+      DomainClassLoaderUCLImpl ucl3 = threadTask.ucl;
       try
       {
          if( threadTask.t == null )
          {
             /* This is a task that has been reassigned back to the original
-            requesting thread ClassLoadingTask, so a new ThreadTask must
+            requesting thread ClassLoadingTaskDCL, so a new ThreadTask must
             be scheduled.
             */
             if( trace )
@@ -448,26 +448,25 @@
          }
       }
 
       // If the ThreadTasks are complete mark the ClassLoadingTask finished
       if( loadTask.threadTaskCount == 0 )
       {
          Class loadedClass = threadTask.getLoadedClass();
          if( loadedClass != null )
          {
             ClassLoader loader = loadedClass.getClassLoader();
-            ClassLoader wrapper = repository.getWrappingClassLoader(loader);
+            ClassLoader wrapper = null;
             if (wrapper != null)
                loader=wrapper;
             // Place the loaded class into the repositry cache
-            repository.cacheLoadedClass(threadTask.getClassname(),
-               loadedClass, loader);
+            //repository.cacheLoadedClass(threadTask.getClassname(), loadedClass, loader);
          }
          /*
          synchronized( loadTask )
          {
             if( trace )
                log.trace("Notifying task of thread completion, loadTask:"+loadTask);
-            loadTask.state = ClassLoadingTask.FINISHED;
+            loadTask.state = ClassLoadingTaskDCL.FINISHED;
             loadTask.notify();
          }
          */
@@ -476,7 +475,7 @@
          {
             if( trace )
                log.trace("Notifying task of thread completion, loadTask:"+loadTask);
-            loadTask.state = ClassLoadingTask.FINISHED;
+            loadTask.state = ClassLoadingTaskDCL.FINISHED;
             loadTaskThreadTasks.notify();
          }
       }
@@ -484,10 +483,10 @@
          log.trace("End nextTask("+taskList.size()+"), loadTask="+loadTask);
    }
 
    /** Complete a ClassLoadingTask. This is called by UCL3.loadClass to indicate
     * that the thread is existing the loadClass method.
     */
-   public static void endLoadTask(ClassLoadingTask task)
+   public static void endLoadTask(ClassLoadingTaskDCL task)
    {
       boolean trace = log.isTraceEnabled();
       if( trace )
@@ -508,7 +507,7 @@
          for(int i = 0; i < size; i ++)
          {
             ThreadTask threadTask = (ThreadTask) taskList.remove(0);
-            ClassLoadingTask loadTask = threadTask.getLoadTask();
+            ClassLoadingTaskDCL loadTask = threadTask.getLoadTask();
             /* Synchronize on loadTask and reassign the thread task back to the
             requesting thread of loadTask. We need to synchronize on loadTask
             to ensure that the transfer of this task back to loadTask.requestingThread
@@ -521,7 +520,7 @@
                // Insert the task into the front of requestingThread task list
                List toTaskList = (List) loadTasksByThread.get(loadTask.requestingThread);
                toTaskList.add(0, threadTask);
-               loadTask.state = ClassLoadingTask.NEXT_EVENT;
+               loadTask.state = ClassLoadingTaskDCL.NEXT_EVENT;
                loadTask.notify();
             }
             */
@@ -533,7 +532,7 @@
             synchronized( toTaskList )
             {
                toTaskList.add(0, threadTask);
-               loadTask.state = ClassLoadingTask.NEXT_EVENT;
+               loadTask.state = ClassLoadingTaskDCL.NEXT_EVENT;
                toTaskList.notify();
             }
          }
@@ -541,7 +540,7 @@
    }
 
    /** Invoked to create a ThreadTask to assign a thread to the task of
     * loading the class of ClassLoadingTask.
     *
     * @param task the orginating UCL3.loadClass task for which the thread
     * @param ucl the UCL3 the ThreadTask will call loadClassLocally on
@@ -551,7 +550,7 @@
     * @param trace the Logger trace level flag
     * @throws ClassNotFoundException
     */
-   static private void scheduleTask(ClassLoadingTask task, RepositoryClassLoader ucl,
+   static private void scheduleTask(ClassLoadingTaskDCL task, DomainClassLoaderUCLImpl ucl,
       int order, boolean reschedule, boolean trace) throws ClassNotFoundException
    {
       Thread t = null;
@@ -145,19 +145,19 @@
     * to load the class from the repository cache, and then the class loaders
     * in the repsository. If the package of the class is found in the repository
-    * then one or more ThreadTask are created to complete the ClassLoadingTask.
+    * then one or more ThreadTask are created to complete the ClassLoadingTaskDCL.
     * The ThreadTask are assigned to the threads that own the associated UCL3
     * monitor. If no class loader serves the class package, then the requesting
@@ -145,19 +145,19 @@
     * @return true if the class could be loaded from the cache or requesting
     * UCL3, false to indicate the calling thread must process the
-    * tasks assigned to it until the ClassLoadingTask state is FINISHED
+    * tasks assigned to it until the ClassLoadingTaskDCL state is FINISHED
     * @exception ClassNotFoundException if there is no chance the class can
     * be loaded from the current repository class loaders.
@@ -448,26 +448,25 @@
       }
 
-      // If the ThreadTasks are complete mark the ClassLoadingTask finished
+      // If the ThreadTasks are complete mark the ClassLoadingTaskDCL finished
       if( loadTask.threadTaskCount == 0 )
       {
@@ -484,10 +483,10 @@
    }
 
-   /** Complete a ClassLoadingTask. This is called by UCL3.loadClass to indicate
+   /** Complete a ClassLoadingTaskDCL. This is called by UCL3.loadClass to indicate
     * that the thread is existing the loadClass method.
     */
@@ -541,7 +540,7 @@
 
    /** Invoked to create a ThreadTask to assign a thread to the task of
-    * loading the class of ClassLoadingTask.
+    * loading the class of ClassLoadingTaskDCL.
     *
     * @param task the orginating UCL3.loadClass task for which the thread

Modified: branches/MC_VDF_WORK/jmx/src/main/org/jboss/mx/loading/ResourceInfo.java
===================================================================